Introduction
============

Before getting heavily into LinchPin, let's cover some of the basics. The topics below will cover everything needed to get going with LinchPin. For more advanced topics, refer to the :doc:`main documentation page <index>`.

.. toctree::
   :tocdepth: 1


* :doc:`installation`
* :doc:`getting_started`
* :doc:`configuration`


.. seealso::

    `User Mailing List <https://www.redhat.com/mailman/listinfo/linchpin>`_
        Subscribe and participate. A great place for Q&A
    `irc.freenode.net <http://irc.freenode.net>`_
        #linchpin IRC chat channel
